"""
工具模块集合
包含数据处理、验证等常用工具类

版本: 1.0.0

使用示例:
    from app.utils import DataUtil, ValidationUtil
    
    # 数据处理示例
    data = {'key': 'value'}
    json_str = DataUtil.to_json(data)
    
    # 验证示例  
    email = 'test@example.com'
    is_valid = ValidationUtil.is_email(email)
"""

__version__ = '1.0.0'

from .date_util import DateUtil
from .data_util import DataUtil
from .file_util import FileUtil
from .network_util import NetworkUtil
from .string_util import StringUtil
from .validation_util import ValidationUtil

# 常用方法快捷调用
to_json = DataUtil.to_json
is_email = ValidationUtil.is_email
is_valid_ip = NetworkUtil.is_valid_ip
get_file_size = FileUtil.get_file_size
get_current_time = DateUtil.get_current_time
format_date = DateUtil.format_date
parse_date = DateUtil.parse_date
get_timestamp = DateUtil.get_timestamp

__all__ = [
    'DataUtil', 'DateUtil', 'FileUtil', 'NetworkUtil', 'StringUtil',
    'ValidationUtil', '__version__', 'to_json', 'is_email', 'is_valid_ip',
    'get_file_size', 'get_current_time', 'format_date', 'parse_date',
    'get_timestamp'
]
